@@ -20,18 +20,35 @@
 
 .. moduleauthor:: Luke Macken <lmacken@redhat.com>
 .. moduleauthor:: Toshio Kuratomi <tkuratom@redhat.com>
+.. moduleauthor:: Ralph Bean <rbean@redhat.com>
 '''
 
-import Cookie
 import copy
-import urllib
-import httplib
 import logging
 # For handling an exception that's coming from requests:
 import ssl
 import time
 import warnings
 
+
+try:
+    from urllib import quote
+except ImportError:
+    # Python3 support
+    from urllib.parse import quote
+
+try:
+    import httplib
+except ImportError:
+    # Python3 support
+    import http.client as httplib
+
+try:
+    import Cookie
+except ImportError:
+    # Python3 support
+    import http.cookies as Cookie
+
 try:
     from urlparse import urljoin
     from urlparse import urlparse
@@ -45,7 +62,7 @@ try:
 except ImportError:
     from sha import new as sha_constructor
 
-from bunch import bunchify
+from munch import munchify
 from kitchen.text.converters import to_bytes
 import requests
 
@@ -321,7 +338,7 @@ class ProxyClient(object):
         # will work with it.
         method = method.lstrip('/')
         # And join to make our url.
-        url = urljoin(self.base_url, urllib.quote(method))
+        url = urljoin(self.base_url, quote(method))
 
         data = None     # decoded JSON via json.load()
 
@@ -347,7 +364,7 @@ class ProxyClient(object):
         complete_params = req_params or {}
         if session_id:
             # Add the csrf protection token
-            token = sha_constructor(session_id)
+            token = sha_constructor(to_bytes(session_id))
             complete_params.update({'_csrf_token': token.hexdigest()})
 
         auth = None
@@ -497,7 +514,7 @@ class ProxyClient(object):
             # Compatibility with newer python-requests
             if callable(data):
                 data = data()
-        except ValueError, e:
+        except ValueError as e:
             # The response wasn't JSON data
             raise ServerError(
                 url, http_status, 'Error returned from'
@@ -516,7 +533,7 @@ class ProxyClient(object):
             new_session = cookie
 
         self.log.debug('proxyclient.send_request: exited')
-        data = bunchify(data)
+        data = munchify(data)
         return new_session, data
 
 __all__ = (ProxyClient,)
